#
# spec file for package cherrytree
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cherrytree
Version:        1.0.4
Release:        1.2
Summary:        A hierarchical note taking application
License:        GPL-3.0-or-later AND LGPL-2.1-only
Group:          Productivity/Office/Other
URL:            https://www.giuspen.com/cherrytree/
Source0:        %{name}-%{version}.tar.xz
#PATCH-FIX-OPENSUSE cherrytree-set-git-version.patch malcolmlewis@opensuse.org -- Set git version in help about.
Patch0:         cherrytree-set-git-version.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  python3-lxml
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(gtksourceviewmm-3.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  pkgconfig(spdlog) >= 1.5
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(vte-2.91)
# For password-protected format
Recommends:     p7zip-full

%description
A hierarchical note taking application, featuring rich text and syntax
highlighting, storing all the data (including images) in a single xml
file with extension ".ctd".

%lang_package

%prep
%autosetup -p1

%build
#Disable build tests as this needs cpputest and static development files!
%cmake -DBUILD_TESTING=OFF -DCT_VERSION=%{version}
%cmake_build

%install
%cmake_install
# Remove old mime registration files
rm %{buildroot}%{_datadir}/mime-info/cherrytree.*
%suse_update_desktop_file -G "Hierarchical Notes Utility" cherrytree TextEditor
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}

%files
%license license.txt
%doc changelog.txt
%{_bindir}/cherrytree
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/net.giuspen.cherrytree.metainfo.xml
%{_datadir}/applications/cherrytree.desktop
%{_datadir}/cherrytree/
%{_datadir}/icons/hicolor/scalable/apps/cherrytree.svg
%{_mandir}/man1/cherrytree.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sun Dec 17 2023 gumsley_6@hotmail.com
- Cumulative update to version 1.0.4:
  + fixed crash when displaying search results dialog (#2398,
    [#2399], #2404, #2405)
  + preferences dialog, keyboard shortcuts, now emphasizing with
    bold the overridden/non default shortcuts (#2397)
  + preferences dialog, keyboard shortcuts, added possibility to
    reset an individual shortcut to the default value
  + changed default keyboard shortcuts to move tree nodes From
    Shift+Arrows to Shift+Alt+Arrows as disrupting the
    functionality of text selection (#2397, #2400)
  + fixed crash when losing access to open document (#2120)
  + fixed crash sorting table (#2391)
  + fixed issues with search/replace and option 'all matches'
  + fixed corrupted export to pdf on mac os with non ascii links
    to files/folders (#2388)
  + multi page search results increased default limit 50->500 and
    configurable in config.cfg 'max_matches_in_page' (#2370)
  + changed all the default keyboard shortcuts using Ctrl+Alt for
    issues on windows with AltGr key (#2341, #2324, #2316, #2124,
    [#2069], #1944)
  + fixed progress bar of search hardly visible on windows (#2373)
  + nodes in bookmark menu to have the correct icon rather the
    anonymous pin icon (#206)
  + fixed node name in bookmarks menu not updated if node renamed
    (#2393)
  + export to pdf, now hiding anchor character (#2379)
  + changed codebox border colour with theme cobalt-darkened as
    hardly visible
  + added option in config.cfg to disable tree, menus and toolbar
    tooltips 'tree_tooltips', 'menus_tooltips',
    'toolbar_tooltips' (#2169)
  + fixed paste of code selection to rich text target adding
    unwanted newline with
  + fixed issue when changing theme in preferences dialog, style
    scheme editor, the change was only applied to the current node
* Fri Sep 29 2023 gumsley_6@hotmail.com
- Update to version v1.0.2:
  + fixed single click on line number to select line, double click
    for pargraph (#1363)
  + multi pages support to all matches dialog, added arrows icons
    for navigation buttons
  + fixed crash when searching with all matches option and the
    text line containing the pattern is very long
  + modified colour of arrow in stock icon ct_download
  + added 42 stock icons
  + added multi pages support to all matches dialog with a limit
    of 50 matches per page (#2019)
  + improved performance of search/replace with option
    'all matches' (#272, #1830, #2019)
  + changed a couple of keyboard accelerators in pl.po
* Tue Aug 29 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.1:
  + Fixed overwrite confirmation not working when saving as new
    multifile storage (#2333).
  + Fixed crash on close (#2302).
  + Fixed xorg crash / wayland warning caused by popup menus
    without a parent (#2328).
  + Fixed paste content copied from column edit mode not working
    in codeboxes.
  + Highlight current text line to be disabled when the text loses
    focus or when the text is in column mode.
  + Reverted 'on windows, paste image from clipboard to take
    priority over html target ...' causing paste from spreadsheet
    cells generating a picture instead of a table.
  + Default keyboard shortcut for increase/decrease table column
    changed to Ctrl+Alt+> Ctrl+Alt+< as Ctrl+) isn't working
    on windows (#2336).
  + Added new stock icon light bulb / internet of things IoT.
  + Added option 'recent_docs' in config.cfg to be set to false
    in order to not remember the recent documents (#2330).
  + Incomplete languages: ar, el, fi, hi_IN, hr, ja, lt, pt.
* Sat Jul 22 2023 gumsley_6@hotmail.com
- Update to version 1.0.0:
  + Fixed crash when opening node properties (#2304, #2313).
  + Fixed blurry output when exporting LaTeX to pdf (#2308).
  + Added configurability of the blinking of the cursor in the
    preferences dialog (#2298).
  + Added support for executing ‘rust’ and ‘go’ code in code nodes
    and codeboxes.
  + Added 61 new stock icons available to be chosen as tree node
    icons.
  + Added menu items under top menu ‘help’ to link to website,
    source code and bug tracker.
  + On Windows, paste image from clipboard to take priority over
    html target containing image so that can work offline
    (#2303, work of @DaPa).
  + Implemented new data storage type: multiple files in
    hierarchical folder structure (#2123, #1823) the backups for
    the new multiple files data storage do not contain all the
    tree but only what has changed.
  + All backup files (or folders for the brand new multifile data
    storage) are now starting with a dot (.name~, .name~~, ..).
  + Fixed crash sorting rows of table lightweight interface
    (#2253).
  + Fix export to html of lists (#2276, #2286).
  + Fixed recent documents corruption when file is deleted/missing
    (#2277).
  + Fixed on Windows zooming the font reverts the font family to
    Sans (#2257).
  + Click on line number to behave as triple click
    (select line, #1363).
  + Column edit (selection with Ctrl+Alt held down) added
    clipboard support (#2232).
  + Remember last selected custom icon in node properties same as
    last selected colour (#2185).
  + Implemented import nodes from indented list (#1551, #2258).
  + Added support for executing java code in code nodes and
    codeboxes.
  + Added detection of exclusions from the search hit in the
    current search and message to the user / how to disable
    exclusions.
  + Fixed in flatpak and appimage languages not available (#2270).
  + Fixed latex box issue with portable version of cherrytree on
    Windows (#2294).
  + Added tooltip with node name when hovering node (#2295).
  + Updated translations.
* Wed Mar  8 2023 malcolmlewis@opensuse.org
- Update to version 0.99.55:
  + Unit tested code to convert lists to HTML.
  + Fixed list element on more lines conversion into real html,
    (gh#giuspen/cherrytree#1765).
  + Implemented conversion of multi level lists into real html
    unordered and ordered lists, (gh#giuspen/cherrytree#1765).
  + Added support for executing c-sharp code,
    (gh#giuspen/cherrytree#2234).
  + Codebox actions: keyboard shortcuts now configurable in
    preferences dialog and available in toolbar configurability.
  + Added missing dependences to Dockerfile for dev container,
    added ms cpp extension pack, (gh#giuspen/cherrytree#2231).
  + Table actions: keyboard shortcuts now configurable in
    preferences dialog and available in toolbar configurability,
    (gh#giuspen/cherrytree#2124, gh#giuspen/cherrytree#2195 and
    gh#giuspen/cherrytree#2219).
  + Removed leftover line no longer needed after latest commit
    about new pdf page bottom numbering.
  + Fixed issue with latest version of cairo in msys2 and pdf
    pages numbering no longer rendered correctly.
  + Recently added autosave options in file save storage not to be
    shown in case of export.
  + Fixed export to pdf crash, (gh#giuspen/cherrytree#2227).
  + Fixed issue with font family name getting multiplied while
    zooming.
  + Fixed autosave in case the document was never saved before, to
    prompt the user for a storage type/path,
    (gh#giuspen/cherrytree#2225).
  + Updated translations.
* Wed Feb  1 2023 malcolmlewis@opensuse.org
- Update to version 0.99.54+1:
  * Fixed crash when creating lightweight table,
    (gh#giuspen/cherrytree#2204).
  * Added menu item action to toggle focus between text and
    integrated terminal with default shortcut Ctrl+Shift+T,
    (gh#giuspen/cherrytree#1772).
  * Added search dialog option to override search exclusions,
    (gh#giuspen/cherrytree#2174).
  * Added menu item action to insert today's node under the
    selected node rather than under the tree root,
    (gh#giuspen/cherrytree#40).
  * Implemented option to keep cherrytree always on top, under top
    menu 'view', (gh#giuspen/cherrytree#2145).
  * Number of table cells to use as threshold for light mode made
    configurable (default 25).
  * Integrated terminal shell configurable in preferences dialog.
  * Fixed issue with integrated terminal when using zsh as default
    shell, (gh#giuspen/cherrytree#2199).
  * Lightweight variant of tables support Ctrl+Space to navigate in
    and out.
  * Lightweight variant of tables entering newline in table cell
    with Ctrl+Enter or Alt+Enter.
  * Dialog all matches improved to show also the node tags and the
    pattern searched.
  * Dialog search with regexp, added help button to display
    reference web page.
  * Fixed searching for regexp everything (.*) freeze,
    (gh#giuspen/cherrytree#2190).
  * Fix title not shown on taskbar button in cinnamon when menubar
    in titlebar.
  * Implementing lightweight variant of tables,
    (gh#giuspen/cherrytree#2140).
  * Updated translations.
- Changes from version 0.99.53:
  * Fixed crash when changing terminal font in preferences dialog
    and terminal never shown in the session,
    (gh#giuspen/cherrytree#2177).
  * Fixed issue of growing encrypted document size when configured
    with no backups, (gh#giuspen/cherrytree#2178).
  * Implementing lightweight variant of tables,
    (gh#giuspen/cherrytree#2140).
  * Updated translations.
* Sat Nov 26 2022 malcolmlewis@opensuse.org
- Update to version 0.99.52:
  * Added support for typescript syntax highlighting,
    (gh#giuspen/cherrytree#2161).
  * Moved encryption and backup to a separate thread; implemented
    verification of the backup before encryption and rotation,
    (gh#giuspen/cherrytree#2148).
  * Linux support path links starting with ~/,
    (gh#giuspen/cherrytree#2149).
  * Code execution: added new tag to allow placing the code
    directly into the terminal rather than in a temporary file,
    (gh#giuspen/cherrytree#1772).
  * Fix import from gnote/tomboy (gh#giuspen/cherrytree#2152,
    gh#giuspen/cherrytree#1991 and gh#giuspen/cherrytree#1686).
  * Fix paste from gnome-characters in fedora,
    (gh#giuspen/cherrytree#2094).
  * Assigned hard coded keyboard shortcut to change codebox
    properties 'Ctrl'+'[', (gh#giuspen/cherrytree#2138).
  * Updated translations.
* Mon Oct 24 2022 malcolmlewis@opensuse.org
- Update to version 0.99.51:
  * Added support for building unit tests with local gtest/gmock
    libraries in new cmake option USE_SHARED_GTEST_GMOCK,
    (gh#giuspen/cherrytree#2089)
  * Fixed import from zim, (gh#giuspen/cherrytree#1870).
  * Fix after getting rid os stringstream.
  * Dropped support for pandoc as implementation relies on
    std::stringstream which is not to be used.
  * Fixed inconsistency between codebox width displayed and printed
    to pdf with auto expand enabled.
  * Translation updates.
* Sun Oct 16 2022 malcolmlewis@opensuse.org
- Update to version 0.99.50+8:
  * Fixed few dialogs missing the property to be destroyed with the
    parent, (gh#giuspen/cherrytree#2133).
  * Better implementation for fixed integrated terminal when
    executing a command for the first time from hidden (not yet
    instantiated) not passing the command.
  * Fixed loss of transparency with PNGs in some GTK3 themes,
    (gh#giuspen/cherrytree#1402 and gh#giuspen/cherrytree#2132).
  * Fixed integrated terminal show/hide command to follow real
    status than settings status.
  * Fixed issue with separator between tree and text not restored
    when tree on right side and window maximised,
    (gh#giuspen/cherrytree#2126).
  * When closing virtual terminal take focus to text rather than
    tree.
  * New integrated terminal - added right click menu and keyboard
    shortcuts to copy and paste.
  * Implemented stricter checks for hard coded keyboard shortcuts
    requiring Ctrl but not Alt, (gh#giuspen/cherrytree#2124).
  * Changed syntax of displayed keyboard shortcuts in toolbar
    tooltips, (gh#giuspen/cherrytree#2128).
  * Just exposing CtrlDown and AltDown from ColumnEdit subclass to
    TextView.
  * Fixed minor issue with exit discarding changes icon not
    visible.
  * Implemented command to execute code from either text selection
    or current line, (gh#giuspen/cherrytree#1772).
  * Adding support for code execution via integrated terminal,
    (gh#giuspen/cherrytree#1902, gh#giuspen/cherrytree#1772 and
    gh#giuspen/cherrytree#547).
  * Translation updates.
- Add build requires VTE 2.91 for new terminal integration.
* Thu Sep 15 2022 malcolmlewis@opensuse.org
- Update to version 0.99.49+3:
  * Legacy_canonicalize_filename: manage empty filename,
    (gh#giuspen/cherrytree#2118)
  * added command line option '--anchor AnchorName' that in
    addition to existing '--node NodeName' allows to open a
    document focusing an anchor in a node.
  * Changed non configurable keyboard shortcuts for codebox width
    and table column width to use parenthesis open instead of
    backslash, (gh#giuspen/cherrytree#2113).
  * Fixed crash on double exit from systray icon right click menu,
    (gh#giuspen/cherrytree#2114).
  * Added keyboard shortcuts to toolbar tooltips,
    (gh#giuspen/cherrytree#2106).
  * Fixed export to HTML crash, (gh#giuspen/cherrytree#2109).
  * Force turning off portal usage since it does not work on all
    distros, (gh#giuspen/cherrytree#2111).
  * Improved dialog confirmation before executing the code.
  * Additonal changes for core22, (gh#giuspen/cherrytree#2110).
  * Allow to disable the dialog asking for confirmation before
    executing the code.
  * Fixed bulleted list unindent (Shift+Tab) crash,
    (gh#giuspen/cherrytree#2103).
  * Add home plug, (gh#giuspen/cherrytree#2101 and
    gh#giuspen/cherrytree#2102).
  * Linux menu launcher run cherrytree in a new instance,
    (gh#giuspen/cherrytree#2077).
  * Fixed crash on print/export as pdf of a sequence of characters
    without spaces longer that the page width, such as a very long
    URL, (gh#giuspen/cherrytree#2045).
  * Fixed wrongly entering column mode when using keyboard
    shortcuts with <Ctrl><Alt> such as insert codebox,
    (gh#giuspen/cherrytree#2075).
  * Added syntax highlighting support for GDScript.
  * Fixed tooltip and cursor not reset after hovering link and then
    navigating to non rich text node.
  * Support for accent insensitive search - added letters with
    subordinate dots, (gh#giuspen/cherrytree#1981).
  * Translation updates.
- Fix duplicate file warnings, add fdupes build requires and macro.
- Developer advised fixed cross-site scripting (XSS) vulnerability
  that allows attackers to execute arbitrary web scripts or HTML
  via a crafted payload injected into the Name text field when
  creating a node, (#boo1202513, gh#giuspen/cherrytree#2099 and
  CVE-2022-35133).
* Wed Jun 29 2022 malcolmlewis@opensuse.org
- Update to version 0.99.48:
  * Added support for right to left languages in export to html and
    pdf (gh#giuspen/cherrytree#2044, gh#giuspen/cherrytree#1668
    and gh#giuspen/cherrytree# #698).
  * In order to support the right to left languages in export to
    html, the resulting html text lines are no longer LINE<br/> but
    <p>LINE</p>.
  * Fixed in export to pdf the link to node+anchor with non ascii
    anchor name.
  * Improved detection of missing executables required for
    rendering LatexBoxes. These dependencies are no longer
    mandatory (gh#giuspen/cherrytree#2033).
  * Added help to the user to show again a hidden menubar
    (gh#giuspen/cherrytree#1927 and gh#giuspen/cherrytree#2054).
  * Pressing Tab on the very latest table cell now adds a new table
    line and moves to its first cell.
  * Fixed issue with relative links to files and folders and
    documents moved between linux and windows.
  * In export to html and txt multiple files, now appending the
    node id to the file names to support multiple nodes with the
    same name.
  * Added syntax highlight support for solidity
    (gh#giuspen/cherrytree#2030).
  * After issues with the domain giuspen.com, the domain changed to
    giuspen.net and giuspen.com will eventually go.
* Thu Apr 21 2022 info@paolostivanin.com
- Update to version 0.99.47+2:
  * Added support for latex math equations.
  * Added copy/paste of tree nodes and subnodes between multiple opened files.
  * Restored support for drag and drop of text selection.
    Now rich text content is preserved.
  * Added syntax highlighting for HCL.
  * Fixed issue at reset toolbar in preferences dialog when menubar in titlebar.
  * Added command line option (-S/--secondary_session) to run in isolation
    from a possibly already running main instance.
  * Updated flatpak script.
* Tue Mar 22 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.46+6:
  * Fixed time created/modified filter on searches for node name and tags.
  * Changed default keyboard shortcuts using Ctrl+Period to Ctrl+Backslash
    for clash with latest linux desktops.
  * Fixed restore window position on Windows and dual screen.
  * Added strip trailing spaces action to rich text right click menu.
  * Fixed issue restoring hpaned tree/text position with tree on the right.
  * Added command line option to pass the password to open an encrypted document.
* Tue Feb  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.45+10:
  * added language Arabic
  * fixed time created/modified filter on searches for node name and tags
  * just ninja build debug print
  * added strip trailing spaces action to rich text right click menu
  * minor improvement to previous commit
  * fixed copy fromm codebox and pasting to rich text unwanted additional characters
* Fri Oct 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.42:
  * Unified search in nodes name+tags and search in nodes content.
  * Fixed search in multiple nodes with the option first from
    selection/first in all range.
  * Fixed issue with password protected data extraction on windows
    and non ascii paths.
  * Link to node insert/edit dialog, added search for anchor
    name in the tree.
  * Implemented node property to exclude node and/or
    subnodes from search.
  * Applying a colour to foreground/background of text
    to use default gtk3 palette.
  * Added in preferenced dialog, tab theme, possibility
    to choose 2 new icon themes.
  * Added option to hide the status bar.
  * Added configurability of selected node's background/foreground
    colour in the tree.
  * Tree explorer added view option to show lines connecting
    the nodes parent-children.
  * Added syntax highlighting for AutoHotkey.
  * Added in preferences dialog, tab fonts, buttons to reset the
    fonts to default values.
  * At F8/current day node do not visit year/month if already
    existing, only day.
  * Support for portable mode in non-windows os looking for
    config/config.cfg beside cherrytree binary executable.
  * Tree sorting menu items: moved siblings only sorting first
    and after separator sorting whole tree.
  * Added experimantal option menubar_in_titlebar that can be
    activated in config.cfg, but off by default.
  * Added flip image buttons to image properties dialog.
  * Rich text tag monospace: added configurability of the
    foreground colour.
  * Fix incorrect insertion from plain text clipboard of
    link with pipe char.
  * Fix apply link to image via toolbar button rather than
    right click.
  * Fix after unmaximise main window, close, reopen -> still
    maximised.
  * Fix fullscreen expands the width of tree explorer rather
    than the editing frame when tree on the right.
  * Fix segfault/crash from exporting imported markdown file
    with a table.
  * Fix todo lists in ubuntu 18.04 not cycling through
    available mark choices.
  * Fix print/export to pdf of table columns widths.
  * Print/export to pdf of scalable tags (h1..h6,small) and
    monospace use configured properties.
  * Node name header font size/family to follow the tree font.
  * Improved table sorting to use not only first column.
  * Improved import from markdown of a table with or without
    pre/post text.
* Mon Aug  9 2021 malcolmlewis@opensuse.org
- Update to version 0.99.40:
  * Just renaming/polishing code of preferences dialog, tab fonts.
  * Fixed blacklist of action that cannot be part of the
    configurable toolbar; removed duplicated exec code action.
  * Translation updates.
- Changes from version 0.99.39:
  * When system tray and start hidden on system tray are enabled,
    load document only after the user click the systray icon to
    show cherrytree, (gh#giuspen/cherrytree#1751).
  * Fix codebox plain text wrongly using code font instead of plain
    text font.
  * Fix TODO lists not working in table cells,
    (gh#giuspen/cherrytree#194).
  * Fix File links in exported PDF do not work when path isn't
    relative, (gh#giuspen/cherrytree#1749).
  * Fixed 'Menu element icons are not always visible',
    (gh#giuspen/cherrytree#1410).
  * Fixed unit test breoken on windows with new utf-8 characters in
    filepath.
  * Unit tests data file use non utf-8 (cyrillic) characters for
    the paths.
* Thu Jul  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.38:
  * Fix crash visiting node with a corrupted/invalid utf-8 character.
  * Fix crash when trying to insert image from file with format not
    supported from Glib such as .webp.
  * Fix unwanted characters found after copy/paste.
  * Fix status icon missing / bad rendered in tray.
  * Fixed tree node visibility issue when starting minimised
    on system tray.
  * Fix link markdown paste broken link.
  * Fix issues with spell check enabled and no languages available.
  * Improved web link recognition.
* Fri May 21 2021 malcolmlewis@opensuse.org
- Update to version 0.99.37:
  * Fix crashing Glib::convert_with_fallback(),
    (gh#giuspen/cherrytree#1593).
  * Fix after undo, redo jumps to the top of the document,
    (gh#giuspen/cherrytree#1151).
  * Assigned keyboard shortcut to move table columns Left/Right:
    Ctrl+{ and Ctrl+}.
  * Assigned keyboard shortcut to move table rows Up/Down: Ctrl+[
    and Ctrl+], (gh#giuspen/cherrytree#1626).
  * Ctrl+Arrows in tables disconnected from cells navigation,
    Ctrl+( and Ctrl+) to navigate Up/Down; Tab and Shift+Tab for
    navigate Right/Left, (gh#giuspen/cherrytree#194).
  * Help--Open Preferences Directory moved under File--Preferences.
  * Fix content in the table can be modified while the node is read
    only, (gh#giuspen/cherrytree#1674).
  * Preferences file export complete.
  * Adding preferences file import/export.
  * ct_menu_actions.cc just splitted too long lines.
  * Added dialog listing all available symbols auto replacements,
    (gh#giuspen/cherrytree#1659).
  * Preserve print page setup settings,
    (gh#giuspen/cherrytree#1664).
  * Fix URL detection doesn't recognize TAB as a delimiter,
    (gh#giuspen/cherrytree#1654).
  * Added configurable option to show the full path in the node
    name header, (gh#giuspen/cherrytree#1399).
  * Preferences dialog language selection explicit label
    'System Default' in place of '-'.
  * Fixed import of text files with extension not .txt on linux,
    (gh#giuspen/cherrytree#1656).
  * Reinstating Gtk::FileFilter::add_mime_type for importing text
    files, (gh#giuspen/cherrytree#1656).
  * Configurability of log enable/disable + directory in
    preferences dialog, tab miscellaneous,
    (gh#giuspen/cherrytree#1614).
  * Preferences dialog, custom backup directory simplified using
    Gtk::FileChooserButton.
  * Configurability of log enable/disable + directory,
    (gh#giuspen/cherrytree#1614).
  * Spell check enabled also for plain text,
    (gh#giuspen/cherrytree#1651).
  * Fix [gtk] [critical] gtk_widget_set_visible: assertion
    'GTK_IS_WIDGET (widget)' failed after,
    (gh#giuspen/cherrytree#1643).
  * Move config.cfg.tmp to config.cfg if not shutting down,
    (gh#giuspen/cherrytree#1614).
  * Added added configurable option to have bookmarks under
    dedicated menu in top menu bar, (gh#giuspen/cherrytree#1643).
  * New configurable scalable tags allow partial
    bold/italic/underline when not on by default,
    (gh#giuspen/cherrytree#1633).
  * Fix SHIFT+ENTER Able to Modify Locked Notes with Lists,
    (gh#giuspen/cherrytree#1640).
  * Translation updates.
- Changes from version 0.99.36:
  * Fix segfault on startup when configured to start on systray,
    (gh#giuspen/cherrytree#1610).
  * Translation updates.
* Fri Apr 16 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.99.35:
  * Fix issue in 0.99.34 H1/H2/H3/H4/H5/H6/small
    not working for certain locale.
  * Fix issue with bookmarks in tree right click menu.
  * Implementation of configurable h1,h2,h3,small + (now supported)
    h4,h5,h6.
  * Reorganised the main menu.
  * Fix undo/redo state machine vertical scrollbar position
    and cursor position.
  * Fix crash when importing text/html files with non ascii
    file name on windows.
  * Fix links to file/folder on windows with UNC path.
  * Detect system shutdown to save config .
  * Improved recognition of web link as you type in case of
    start with ({[, end with ,;.)}].
  * Fixed wheel click on file link (to open parent folder).
  * Fix zooming text/tree font not being properly enforced like
    preferences dialog does.
  * Enabled logging to config folder, max size 5MB.
* Sun Mar 28 2021 malcolmlewis@opensuse.org
- Update to version 0.99.33+5:
  * Modified main menu, (gh#giuspen/cherrytree#1573).
  * Added automatic syntax highlighting for the Dart language,
    (gh#giuspen/cherrytree#1569).
  * Fix changing codebox width of codeboxes with width in
    percentage, (gh#giuspen/cherrytree#1556).
  * Correct the FSF's postal address, (gh#giuspen/cherrytree#1566).
  * Fix import from cherrytree file missing dialog asking for
    parent node, (gh#giuspen/cherrytree#1562).
  * Treat equally return key press and numeric keypad enter key
    press, (gh#giuspen/cherrytree#1547).
  * Translation updates.
* Mon Mar 15 2021 malcolmlewis@opensuse.org
- Update to version 0.99.32:
  * Fix crash regression of latest changes to restor excat vertical
    scrolling of text.
  * Remember last inserted special character and focus it at next
    special char insert time.
  * Improved restoring of exact vertical scroll position,
    (gh#giuspen/cherrytree#1151).
  * Fix iterated find dialog position issue.
  * Non rich text is to use the standard gtk undo/redo.
  * Fix iterated find/replace dialog disappearing after first
    button click.
  * Improved dialog to select an item in the list focusing the item
    that is currently in use.
  * Fixed issue with tree on right side restore tree width;
    splitted ct_main_win.cc, (gh#giuspen/cherrytree#1534).
  * Updated ct_node_no_icon.svg.
  * Close image resize dialog when pressing enter; dialog.cc split,
    (gh#giuspen/cherrytree#1547).
  * More node icons (gh#giuspen/cherrytree#1514).
  * Fix copy as plain text not working in table cell,
    (gh#giuspen/cherrytree#1528).
  * Cycle cherries colors in nodes levels rather than use the
    latest level for all exceeding number of colors,
    (gh#giuspen/cherrytree#692).
  * Added support for language 'elixir',
    (gh#giuspen/cherrytree#1541).
  * Update README.md, (gh#giuspen/cherrytree#1536).
* Fri Feb 26 2021 malcolmlewis@opensuse.org
- Update to version 0.99.31+1:
  * Fix for building with ninja/cmake generator for ninja
    (-GNinja).
  * Amsys2 script to prepare standalone folder added user-style.xml
    required for user custom styles(themes).
  * Added few more icons as selectable for custom node icon,
  (gh#giuspen/cherrytree#1514).
  * Preferences dialog menu languages added flags,
    (gh#giuspen/cherrytree#1511)
  * Fixed import from keepnote missing images,
    (gh#giuspen/cherrytree#1516).
  * Added button to reset the two user style schemes to the default
    palettes.
  * Fix cmake install target, (gh#giuspen/cherrytree#1521).
  * Two user style schemes, one with a light default and one with
    a dark default.
  * Reworked pref dialog tab themes to make room for second user
    style scheme.
  * Independent style scheme for plain text and code.
  * Working on user theme editor, (gh#giuspen/cherrytree#1362).
  * Split pref dlg source file for upcoming work on theme editor.
  * Removed default global shortcut Ctrl+Delete to delete tree node
    because overrides text editor standard,
    (gh#giuspen/cherrytree#1513).
  * Insert special symbols chenged from submenu items to dialog,
    (gh#giuspen/cherrytree#1503).
  * Renamed filesystem path methods .string_native() and
    .string_unix().
  * New unit test for export to html.
  * New unit test for export to pdf.
    + unit test for export to txt; unit tests now in 3 binaries
    'run_tests_no_x', 'run_tests_with_x_1', 'run_tests_with_x_2'.
  * Implemented 'format clone' at cursor which can be applied with
    existing 'format latest', (gh#giuspen/cherrytree#600).
  * Translation updates.
* Sun Jan 31 2021 malcolmlewis@opensuse.org
- Update to version 0.99.30+7:
  * Fixed misleading command line argument export to pdf name - the
    user is expected to pass a directory path, not a file path.
  * Updated tests/googletest to current master HEAD to get rid of
    cmake warnings.
  * Replaced few Gio::File with g_file because of unit tests
    issues.
  * Moved a couple of types to proper header and fixed a unit test.
  * Insert link dialog to remember/repropose last selection,
    (gh#giuspen/cherrytree#1413).
  * Fix export to pdf crash.
  * Improved language selection in preferences dialog,
    (gh#giuspen/cherrytree#1496).
  * Moved top menu items 'Edit'->'Preferences' and 'Tree'->'Tree
    Info' to 'File' menu, (gh#giuspen/cherrytree#1497).
  * Cmake option to not automatically run the unit tests
  - DAUTO_RUN_TESTING='', (gh#giuspen/cherrytree#1433).
  * Versioning 48px variant of the icons, not currenlty in use,
  (gh#giuspen/cherrytree#1451).
  * New ct_code.svg, (gh#giuspen/cherrytree#1451).
  * Fix when creating new node/subnode not proposing syntax
    highlighting of selected node, (gh#giuspen/cherrytree#1481).
  * Update README.md - Added build description,
    (gh#giuspen/cherrytree#1488).
  * Fix Table of Contents not saving, (gh#giuspen/cherrytree#1484).
  * Fix crash when importing CSV file,
    (gh#giuspen/cherrytree#1476).
* Sat Jan  9 2021 malcolmlewis@opensuse.org
- Update to version 0.99.29:
  * Fix unable to open sqlite document created with old document
    version, (gh#giuspen/cherrytree#1471).
  * Add meta modifier shortcut key support,
    (gh#giuspen/cherrytree#1467).
* Sun Jan  3 2021 malcolmlewis@opensuse.org
- Update to version 0.99.28:
  * Improved sanitisation from bad characters at xml parse time,
    (gh#giuspen/cherrytree#1465).
  * Fix config.cfg re-created when symlinked,
    (gh#giuspen/cherrytree#1464).
  * Found better workaround for visualisation glitches,
    (gh#giuspen/cherrytree#1416, gh#giuspen/cherrytree#1427,
    gh#giuspen/cherrytree#1446 and gh#giuspen/cherrytree#1447).
  * Fix regression speeding up tables.
  * Support for sqlite document generated with old version of
    cherrytree, alter only at write time.
  * Isolating and trying to find alternative to
    WORKAROUND_ANCHORED_TEXT_VISUAL_GLITCHES.
  * Working on tables poor performance.
* Sun Dec 27 2020 malcolmlewis@opensuse.org
- Update to version 0.99.27+13:
  * Fix using fmt always unbundled from spdlog,
    (gh#giuspen/cherrytree#1458).
  * Using fmt always unbundled from spdlog,
    (gh#giuspen/cherrytree#1458).
  * Fix time filter for find in nodes names and tags,
    (gh#giuspen/cherrytree#1453).
  * Fix color for selected item in tree not consistent with
    selected item in menu, (gh#giuspen/cherrytree#1456).
  * Do not bundle spdlog but use as external library,
    (gh#giuspen/cherrytree#1199 and gh#giuspen/cherrytree#1433).
  * Fix failed zim import, (gh#giuspen/cherrytree#1273).
  * Changed GPG signature to detached,
    (gh#giuspen/cherrytree#1433).
  * Icon theme new save and other improvements.
  * More GCC11 fixes. (gh#giuspen/cherrytree#1450).
  * Translation updates.
- Add pkgconfig(spdlog) and pkgconfig(fmt) to build requires
  since no longer bundled.
* Mon Dec 21 2020 malcolmlewis@opensuse.org
- Update to version 0.99.26+2:
  * Fix select text with keyboard not working,
    (gh#giuspen/cherrytree#1441).
  * Fix crash when trying to paste invalid image in clipboard,
    (gh#giuspen/cherrytree#1440).
  * Fix open folder link not working when non ASCII path,
    (gh#giuspen/cherrytree#1423).
  * Fix recent documents list does't show undescores,
    (gh#giuspen/cherrytree#1435).
  * Keyboard shortcut to delete a node becomes Ctrl+Delete since
    this action now works also with focus on the text/while editing
    text, (gh#giuspen/cherrytree#1412).
  * Icon theme fixes/improvements, (gh#giuspen/cherrytree#1426,
    gh#giuspen/cherrytree#1414).
  * Fix find function adds empty lines to blank nodes,
    (gh#giuspen/cherrytree#1428).
  * Removed code duplications for open file and folder link,
    (gh#giuspen/cherrytree#1423).
  * Fix crash trying to open a bookmarked node that was deleted,
    (gh#giuspen/cherrytree#1430).
  * Fix wrongly detecting being run from the sorces directory build
    folder, (gh#giuspen/cherrytree#1422).
  * Fix non working keyboard shorcuts Alt+Left/Right to go to
    previous/next visited nodes, (gh#giuspen/cherrytree#1412).
  * Fix tree drag n drop freezing issue,
    (gh#giuspen/cherrytree#1377).
  * Fix table keyboard shortcut Ctrl+comma (add row) and
    Ctrl+Alt+comma (delete row), (gh#giuspen/cherrytree#1417).
  * When (re)generating TOC do not remove anchors created from the
    user, (gh#giuspen/cherrytree#1382).
  * Translation updates.
* Wed Dec  9 2020 malcolmlewis@opensuse.org
- Update to version 0.99.25:
  * Fixed unit test.
  * Icon theme update, (gh#giuspen/cherrytree#1408).
  * Debugging too slow large tables...
  * Added missing tooltips on the bookmarks handle dialog,
    (gh#giuspen/cherrytree#1403).
  * Fix spell-check language selection from right click menu was
    not saved to preferences.
  * Fix spell-check language selection from poreferences dialog not
    working (but ok from right click menu),
    (gh#giuspen/cherrytree#1400).
  * Fix TOC generation when existing anchor but wrong name,
    (gh#giuspen/cherrytree#1382).
  * Allow to override build date with SOURCE_DATE_EPOCH,
    (gh#giuspen/cherrytree#1401).
  * Improved command line switch --new-window,
    (gh#giuspen/cherrytree#1339).
  * Export to plain text do not alter node name case and prefix
    with a # per node level, (gh#giuspen/cherrytree#1385).
  * Fix the cherrytree shebang, (gh#giuspen/cherrytree#1396).
  * Translation updates.
* Tue Dec  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update _service:
  + Change to @PARENT_TAG@+@TAG_OFFSET@ version scheme comonly used
    by the GNOME Team (with +0 being stripped when detected).
* Tue Dec  1 2020 malcolmlewis@opensuse.org
- Update to version 0.99.24+git20201130.67860cc0:
  * Fix can't open encrypted .ctx/.ctz file when the filename is
    renamed, (gh#giuspen/cherrytree#1383).
  * Fix missing copy/cut/paste for tables and codeboxes in right
    click menu, (gh#giuspen/cherrytree#1379).
  * Fix insert TOC with closing bracket at the end of the headline,
    (gh#giuspen/cherrytree#1382).
  * Fixes setting date in Gtk::Calendar,
    (gh#giuspen/cherrytree#1386).
  * Fix crash parsing sqlite node with image,
    (gh#giuspen/cherrytree#1337).
  * New --export_single_file export option,
    (gh#giuspen/cherrytree#1371).
  * Fix Automatically Check for Newer version,
    (gh#giuspen/cherrytree#1380).
  * Flatpak build fix (needs --share=network).
  * Run the unit tests automatically if you build them.
  * Packaging cleanup.
  * Exploit advantage of google parameterised tests.
  * Added now required after clone for building the unit tests 'git submodule update --init'.
  * Suppress gtk warning during unit tests.
  * Migration to google test.
- Changes from version 0.99.23:
  * Debugging flatpak crash.
* Tue Nov 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.99.22+git20201123.fea3e66c:
  * fixed not saving node properties when only node properties
    are changed (#1364)
  * fix issue (gitch) pasting tables from clipboard (#1358)
  * added command line switch --new-window (#1339)
  * the rich text tagged monospace is not forced to use a dedicated
    font anymore - configurable and off by default (#1343)
* Sat Nov 21 2020 malcolmlewis@opensuse.org
- Update to version 0.99.21+git20201121.e0afb5a6:
  * Fix typos in README, (gh#giuspen/cherrytree#1357)
  * Fix 7za sources License.txt issue,
    (gh#giuspen/cherrytree#1356).
  * Fix unit tests after latest changes for new arg option
  - -new-window.
  * Adds --new-window option, (gh#giuspen/cherrytree#1355).
  * Fix issue with clipboard on windows,
    (gh#giuspen/cherrytree#1336, gh#giuspen/cherrytree#1344 and
    gh#giuspen/cherrytree#1341).
  * Suppress error when test a wrong password,
    (gh#giuspen/cherrytree#1350).
  * Table will contain right amount of column widths; removes table
    to xml copy-paste, (gh#giuspen/cherrytree#1349).
  * Fixes crash in html parser due to <li> without <ul>,
    (gh#giuspen/cherrytree#1348).
  * Fix crash when triying to move a table column,
    (gh#giuspen/cherrytree#1342).
  * Fix crash when pasting HTML, (gh#giuspen/cherrytree#1346).
  * Translation updates.
- Added cherrytree-set-git-version.patch and rebase since we are
  pulling from git again.
* Tue Nov 17 2020 info@paolostivanin.com
- Update to version 0.99.20+git20201116.736ca99f:
  * New: rewritten everything from scratch in C++/GTK3
  * New: Export to PDF support for hyperlinks
  * New: Export to HTML option to produce a single file
  * New: Duplicate a node and its subnodes
  * New: Option to scroll beyond the last line, enabled by default
  * New: The rich text does no longer have light/dark/custom theme
    but a range of themes to select from like already
    for plain text & code
  * New: Tables also can select their own theme like rich text
    and plain text & code
  * New: You can now right click a node or an anchor and select to
    copy a link to it in the clipboard, then paste
    the link into rich text
  * New: Formatting tag to indent/unindent
  * New: The tables are implemented with a different library widget,
    editing a cell is easier, Ctrl+Arrow to move cursor between cells
  * New: For both codeboxes and tables, Ctrl+Space allows to move
    the cursor in and out
  * New: Rich text, monospace tag has the font configurable
    in the preferences dialog
  * New: Column edit mode scintilla-like holding down Ctrl and Alt
    and selecting the column (cut/copy/paste not yet supported)
  * New: Foreground and background tags in the rich text can be
    removed without altering the other tags
  * New: The cherrytree backup files can be saved in a configured
    directory rather than the document directory
  * New: Code build/execution, in preferences dialog it is
    configurable also the file extension of the
    temporary generated file
  * New: Import from markdown file/folder
  * New: Option for markdown auto replacement to rich text
  * New: The toolbar supports multiple rows of icons
  * New: Filetype icons for file attachments on Linux
  * New: it is configurable whether to wrap or not the nodes
    names in the tree, off by default
  * New: Now configurable from the preferences dialog are the
    "Embedded file size limit", "Triple click to select the
    whole paragraph", "Chars for bulleted list", "Chars for
    todo list", "Chars for table of content", "Chars for smart
    double quote", "Chars for smart single quote"
  * New: It is configurable whether to show the document directory
    in the window title or not
  * complete changelog can be found here:
    https://github.com/giuspen/cherrytree/blob/master/changelog.txt
- Removed cherrytree-set-git-version.patch
* Thu Jun 11 2020 malcolmlewis@opensuse.org
- Fix lang filelist creation, ensure in build dir before running
  find_lang macro.
* Wed Jun 10 2020 malcolmlewis@opensuse.org
- Updated to latest git release 0.39.3+git20200610.9e116177:
  - Build version from 'future' branch with cmake.
- Changes from version 0.39.3:
  * Forbid to use '<' and '>' in password in PyGtk2,
    (gh#giuspen/cherrytree#765) - all characters will be available
    in upcoming Gtkmm3 version currently under testing.
  * After toggle tree visibility with tree that becomes visible,
    the tree gets the focus (tree gets hidden, text gets the
    focus).
  * Possibility to disable triple click selecting the whole
    paragraph, currently only editing directly config.cfg
    (look for triple_click_paragraph).
  * Translation updates.
- Changes from version 0.39.2:
  * Fix very slow node creation, (gh#giuspen/cherrytree#686).
  * Fix Wrong "." processing in "Replace in Nodes Names" (RegExp
    mode), (gh#giuspen/cherrytree#689).
  * Fix for table's cell content lost unless you explicitly press
    Enter, (gh#giuspen/cherrytree#700).
  * Fix Control/command key deselects (un-highlights) text in
    table, (gh#giuspen/cherrytree#699).
  * Fix Keyboard shortcuts for sorting do not work,
    (gh#giuspen/cherrytree#305).
- Changes from version 0.39.1:
  * Fixed export to html regressions after 0.39.0,
    (gh#giuspen/cherrytree#668).
  * Fixed RuntimeError: returned character can not be represented
    in 16-bit unicode", (gh#giuspen/cherrytree#675,
    gh#giuspen/cherrytree#664).
  * Fixed problem with opening another note,
    (gh#giuspen/cherrytree#679).
  * Show node path in tooltip of Last Visited Nodes,
    (gh#giuspen/cherrytree#680).
  * Triple click functionality to select paragraph limited to rich
    text as not ideal in particular for for code.
- Changes from version 0.39.0:
  * Improved export to html.
  * Fixed export to pdf, picture blurry.
  * Implemented a 'command palette' dialog to quickly access all
    the commands in one place.
  * Improved sorting.
  * Improved performance of imports into cherrytree.
  * Fixed 'recent document paths have wrong enconding',
    (gh#giuspen/cherrytree#632).
  * Fixed 'visited nodes history, going to todays node using key
    binding'.
  * Fixed 'syntax Highlighting selected first from list when
    pressing enter', (gh#giuspen/cherrytree#657).
  * Updated syntax highlighting language specs files for various
    languages, (gh#giuspen/cherrytree#228,
    gh#giuspen/cherrytree#92 and gh#giuspen/cherrytree#38).
  * Cursor to stay inside codeBox after creation,
    (gh#giuspen/cherrytree#655), remember: Ctrl+Space moves the
    cursor in and out the codebox.
  * Added triple click functionality to select paragraph.
  * Fixed smart quotes spell check bug.
  * Added new language Swedish.
- Changes from version 0.38.11:
  * Fixed regression of 0.38.10, could no longer print.
- Changes from version 0.38.10:
  * Bugfix: Error opening encrypted documents when path contains
    non-ASCII characters, (gh#giuspen/cherrytree#399).
  * Bugfix: removing the text formatting was possible in read-only
    Node, (gh#giuspen/cherrytree#543).
  * Bugfix: collapse all nodes at startup doesn't work with enabled
    expand tree at mouse click, (gh#giuspen/cherrytree#569).
  * Added support for export to pdf from command line,
    (gh#giuspen/cherrytree#584).
  * Supporting new syntax highlighting for language kotlin.
  * 'reload after external update to ct* file' disabled by default,
    (gh#giuspen/cherrytree#602).
  * 'smart quotes auto replacement' replacing characters
    configurable manually editing config.cfg.
  * Added small sigma to default special chars,
    (gh#giuspen/cherrytree#563).
  * Added dollar as character not to be used in passwords; note
    that all chars will be instead usable in upcoming gtkmm3
    version, (gh#giuspen/cherrytree#545).
  * Minor changes to support reading a document that has been
    edited from the upcoming gtkmm3 version of cherrytree.
  * Minor changes to support reading a config.cfg that has been
    edited from the upcoming gtkmm3 version of cherrytree.
- Add cherrytree-set-git-version.patch: Set git version in help
  about.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Nov 24 2019 malcolmlewis@opensuse.org
- Update to version 0.38.9:
  + Auto replacement of symbols as you type is now configurable in
    preferences dialog, tab Text.
  + Ctrl+Space to toggle To-Do List Item State; fixed multilevel
    bug.
  + Paste/import from html – added basic support.
  + In codeboxes use code font for both plain text and syntax
    hilighting.
  + Fix paste as plain text into CodeBox cause losing CodeBox
    content (#538).
  + Export to html, stylesheet revamp.
- Run spec-cleaner.
- Add python-xml to requires.
* Sat Mar  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.38.8:
  + Improved implementation of deletion of recent documents entry.
  + Ctrl+Space to toggle To-Do List Item State.
  + Fix detection of missing installation of xterm required in code
    execution on linux (with default settings).
  + Horizontal rule insert without hard coded newline before (still
    newline after).
  + Updated translations.
- Changes from version 0.38.7:
  + Bugfix:
  - Problem of locale.getdefaultlocale behavioural change in
    python.
  - Must not allow deletion of a node that is read only.
  + Allow deletion of a recent documents entry via entry submenu.
  + Renamed two iterated find dialog labels from Find & Find to
    Find Previous & Find Next.
  + Moved python-appindicator from Depends: to Recommends:
  + Export to html, include node name not working without links
    tree.
- Changes from version 0.38.6:
  + Bugfix:
  - Do not throw error when failing to clean temporary directory.
  - Workaround for locale.get issues.
  - Import from html of table error resulting in paste from
    clipboard error.
  - Multilevel numbered lists not restarting from one.
  - Wrap line with a single very long word.
  + Todo list characters configurable in config.cfg.
  + Import from zim, support for codebox.
* Fri Jul  6 2018 antoine.belvire@opensuse.org
- Update to version 0.38.5:
  + Bugfixes:
  - When save on exit is enabled and write to disk fails, changes
    are lost (gh#giuspen/cherrytree#358).
  - Superscript and subscript tags not recognized when copied
    from external source (gh#giuspen/cherrytree#355).
  - Workaround for bug in locale module
    (gh#giuspen/cherrytree#368).
  + Added syntax highlighting for go language.
  + Implemented support for opening a text file from the command
    line with cherrytree.
* Mon Jul  2 2018 kstreitova@suse.com
- Recommends p7zip-full for TW as 7za binary used in cherrytree was
  moved there
* Thu Feb  8 2018 bjorn.lie@gmail.com
- Update to version 0.38.4:
  + Support for zoom in tables with both Ctrl+Mouse Wheel or
    Ctrl+Plus/Minus.
  + Copy/paste rich text with dark background to light background,
    fix too light color.
  + Tree visible status now persistent after system tray hide/show
    and between sessions.
  + Default value changes for web link color (less bright blue) and
    codebox auto resize (to False).
  + No special chars auto replacements for code – only for rich and
    plain text.
  + Paste from rich text and import from html – support fot tag
    <code> to codebox.
  + Tab key also valid to switch between table cell.
- Changes from version 0.38.3:
  + Bugfix saving sqlite document (syntax error).
  + Plain text to have font independent from rich text.
  + Right click menu inside of codeboxes, added cut/copy as plain
    text.
  + Paste rich text from clipboard fix.
  + HTML-export IOError: 'filename too long'.
  + Bugfix in export to pdf.
* Sat Sep  2 2017 luc14n0@linuxmail.org
- Update to version 0.38.2:
  + Bug fixes:
  - In importing from cherrytree file (links broken).
  - In exporting to HTML (‘#’ in node name).
  - The problem with underscoring character in recent filenames.
  - The problem with importing from keynote.
  + Left arrow key press with focus on an already collapsed
    tree node, now moves the selection to the node parent.
  + Added right click menus cut & copy as plain text to the
    automatic syntax highlighting nodes.
* Wed Jan 25 2017 zaitor@opensuse.org
- Update to version 0.37.6:
  + Added auto apply of links to nodes as you type [[node name]] in
    rich text nodes.
  + The text formatted monospace has now by default gray.
  + background; configurable in config.cfg.
  + Fixed problem causing the highlighted line to have wrong
    background.
  + Fixed crash caused by too large tooltip hovering a link.
  + Updated translations.
- Changes from version 0.37.5:
  + Tthe password protected documents now use 7zip fastest
    compression resulting in faster save and slightly larger
    documents.
  + Added auto apply of web links as you type in rich text nodes.
  + Added auto apply of links to nodes as you type in rich text
    nodes (CamelCase nodes names only).
  + Added proper scrolling to cursor after pasting of multiple
    lines of text from the clipboard.
  + Added palette to the color picker dialog for the node name.
  + Fixed bugs related to export to pdf of tables and codeboxes.
  + Limited the spell check to rich text nodes after currently
    unresolvable problems with plain text spell check.
- Changes from version 0.37.4:
  + Bugfix: regression since 0.37.0 for trees with more than 11
    levels and cherries per node level.
  + Added groovy language syntax highlighting support.
  + Updated translations.
- Changes from version 0.37.3:
  + Bugfix: problem with sqlite storage (ctb, ctx), bold node name
    and plain text node.
  + For the document type XML (ctd, ctz) changed the generated XML
    to be pretty (indented).
  + Change to slightly larger 'small font' in formatted text.
* Fri Jul 15 2016 luke.nukem.jones@gmail.com
- Update to version 0.37.2:
  + fixed problems introduced with configurability of the bulleted
    lists chars.
  + fixed problem with search in selected node and subnodes and
    progressbar.
  + the latest applied formatting is now remembered between
    sessions.
  + the Ctrl+Space shortcut now allows to enter and exit the
    codeboxes.
  + updated translations.
- Changes from version 0.37.1:
  + bugfix: import of text documents bad decoding (added new
    dependency python-chardet).
  + bugfix: copy/paste of table row not working.
  + the chars used for the multi level bulleted lists are
    configurable editing config.cfg (editor/chars_listbul).
  + the chars used for the toc are configurable editing
    config.cfg (editor/chars_toc).
  + updated translations.
* Sun May 29 2016 zaitor@opensuse.org
- Update to version 0.37.0:
  + Implemented configurability of most of the keyboard shortcuts
    (few of them cannot be changed).
  + Implemented quick access to last visited nodes with
    configurable number of buttons on the node name header.
  + Implemented the possibility to select from a list the default
    icon for all the (non code) nodes in the tree; code nodes have
    by default explicit icons related to the programming language.
  + Implemented the possibility for any node to set an icon from a
    list.
  + Implemented the possibility for any node to set color and
    boldness for the node name.
  + Implemented control of the vertical space around lines.
  + Implemented the possibility to disable the smart quotes auto
    replacement.
  + Implemented the option to have the links underlined or not.
  + Implemented the tree node action “move right” to make a node
    son of the above sibling; taking shortcut Shift+Right.
  + Implemented the possibility at mouse click on the node to
    expand it and to have the focus moved to the text.
  + Implemented the import from RedNotebook.
  + Added in the preferences dialog the possibility to reset to the
    default values the toolbar and the special characters.
- Changes from version 0.36.9:
  + New icons for codebox and table, fixed icon for image.
  + Updated translations.
- Changes from version 0.36.8:
  + Fixed bug in font zoom in/out on tree and text with ctrl down
    and mouse wheel up/down.
- Changes from version 0.36.7:
  + Implemented font zoom in/out on tree and text with ctrl down
    and mouse wheel up/down.
  + Implemented auto replace as you type of single and double
    quotes with smart quotes.
  + Export to html: it is now possibile to override the default
    styles.css in the preferences dir.
  + Updated icons of rich text color foreground/background.
  + Updated translations.
- Changes from version 0.36.6:
  + Fixes in exports to html, pdf, txt.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 0.36.5:
  + Fixed color of highlighted line in rich text with light
    background.
  + Fixed generation of pdf with colors coming from dark background
    not suitable for white background.
  + Fixed missing checks in read only nodes.
  + Fixed problem with html pasted from clipboard.
  + Updated translations.
* Sun Feb  7 2016 mailaender@opensuse.org
- Update to version 0.36.4
  + Added the configurable option to highlight the current line
    also for rich text nodes.
  + Spell check working in both rich text and plain text nodes (not
    in code nodes).
  + Special chars auto-replaced: “==> ” becoming “⇒ “, “<== ”
    becoming “⇐ ” and “<=> ” becoming “⇔ “.
  + Added support for “rust” programming language syntax
    highlighting.
  + Bugfix in duplicating nodes with images and tables.
  + Bugfix in lists change level and in numbered lists start with
    selected text.
  + Bugfix in insertion of today’s node (F8) and non ascii chars.
  + Bugfix copying from plain text to rich text and automatic web
    link formatting.
  + Updated translations.
* Thu Dec 31 2015 badshah400@gmail.com
- Update to version 0.36.3:
  + Bugfix in searches.
  + Added syntax highlightings Markdown and Markdown Extra.
- Changes from previous versions:
  + See /usr/share/doc/packages/cherrytree/changelog.txt.
* Thu Jul  9 2015 zaitor@opensuse.org
- Update to version 0.35.9:
  + Export to HTML now supports also the embedded files.
  + Cursor position not restored after closing and reopening the
    main window.
  + When pressing Tab with a table focused, do not delete the table
    but put the cursor after the table.
  + Toolbar and node name header visibility state not
    saved/restored properly with system tray docking enabled.
  + Import from zim: improved preserving of links between nodes.
  + Updated translations.
* Thu May 28 2015 zaitor@opensuse.org
- Update to version 0.35.8:
  + Protected documents: better checks at extraction time to cope
    with 7zip extracting zero size files after a wrong password.
  + Protected documents bugfix: windows 7za.exe wrong path detected
    causing wrong password error.
  + Import from plain text file in WIN_OS allow user to select an
    extension different than txt (in linux any text file is
    automatically detected).
  + Changed behaviour of HOME and END key presses in text: at first
    press move the cursor to start or end of the line, at second go
    to smart start or end (start or end excluding spaces).
  + Dialog tablecolumnhandle: change active radiobutton with Tab
    and auto focus to text entry.
  + Added support for Scala programming language (from
    gtksourceview-3.0/language-specs).
  + Bugfix in import from html and notecase and nested span tags
  + Bugfix: changing a node syntax highlighting from code to plain
    text and vice versa did not update the font.
  + Bugfix: if a node has the read only property set, do not let
    the user change the node type.
  + Bugfix: after changing node type from rich to non rich text,
    the undo removes all text.
  + Bugfix: preferences dialog, the timestamp format help button
    was linked to a web page listing options not implemented in the
    python version; now the link goes to the exact python
    implementation.
* Mon Feb  2 2015 dimstar@opensuse.org
- Update to version 0.35.7:
  + Improved checks at password protected documents save time after
    reports of data loss in windows os.
  + Updated translations.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 0.35.6:
  + The middle (or wheel) click on a link to file or folder opens
    the parent directory of the target file or folder.
  + Added tree right click menu item to bookmark the selected node.
  + Bugfix in reading a cherrytree XML document.
  + Bugfix in relative links click.
  + Bugfix in import from treepad lite.
  + Updated translations.
- Changes from version 0.35.4:
  + Bugfix:
  - Conversion from rich text to plain text of links results in
    the link target only if the link is the sole text copied and
    is not a link to node.
  - Relative links are to be relative to the document folder and
    not to the executable folder.
  - Right click over a selection including a link causes
    deselection if the right click is over the link.
  - Import from tuxcards.
  - Paste from firefox on windows with russian language page.
  - Paste text in a codebox causing an auto resize, change node
    without saving before, go back to the older node, the text
    pasted in the codebox is lost.
  + Changed automatic conversion from ascii chars to “todo list”
    from “[ ] ” to “[] ".
- Changes from version 0.35.4:
  + Bugfix:
  - Export to plain text and conversion from rich text to plain
    text problems in 0.35.3.
  - Automatic list set after inserting "* " and "[ ] " problems
    in 0.35.3.
  - Crash in codebox auto expansion.
  - Crash loading the links dialog.
- Changes from version 0.35.3:
  + Fixed bugs in copying rich text between cherrytree, libreoffice
    and gmail preserving the rich text properties; as a consequence
    the html import/export was improved.
  + Fixed bugs in importing text files with non utf-8 encoding.
  + Fixed bug in automatic word selection when applying a
    formatting.
  + Fixed bug in TOC not recognizing headers.
  + Fixed bug causing the codeboxes with automatic expansion to
    crash.
  + Fixed bugs in the conversion between the three list types.
  + Changed the behaviour of the direction arrows in the tree
    navigation: the left key collapses the node, the right key
    expands the node, the up and down arrows move the selection up
    and down not only between siblings (as it was before) but in
    the whole tree.
  + Links copy and paste: when converting from a rich text source
    to a plain text destination, now the link target is preserved,
    the link label is dropped.
  + Improved the links dialog navigation: the Tab key toggles
    between the link types, the tree is navigable using the four
    direction arrows and typing text while the focus is on the tree
    searches for a node name.
  + Added “Common Lisp” syntax highlighting definition from
    kfyatek-dev.jogger.pl.
  + Fixed bugs in import from KeyNote.
  + Other minor fixes.
- Changes from 0.35.2:
  + Bugfix: drag n drop with destination before the first sibling.
  + Bugfix: codebox memory of latest used settings.
  + Updated translations.
- Changes from version 0.35.1:
  + bugfix: pressing cancel on node add/edit dialog still inserts
    corrupted node.
- Changes from version 0.35.0:
  + The toolbar is now configurable in a dedicated preferences
    dialog tab.
  + Added configurable option to use relative paths in links to
    files and folders.
  + Added limit of 10 MB to embedded files. embedding larger files
    is not safe.
  + Implemented the possibility to open embedded files with double
    click or right click menu.
  + The embedded files have now the time of latest edit and the
    size visible in tooltip.
  + Added configurable option to have codeboxes expand
    automatically.
  + The following commands now work also inside of the codeboxes:
  - text row cut/copy/delete/up/down, text change case, text
    duplicate, insertion of special chars, timestamp, horizontal
    rule, lists handling.
  + Added right click menu to cut, copy and delete embedded files
    and anchors.
  + Added menu item and shortcut (Ctrl+Alt+R) to toggle the Read
    Only property of the selected node.
  + When we double click on text we are used to see the word under
    mouse to be selected. Now it is possible in configuration to
    add chars to include in the selection (e.g. adding ‘@’ you
    select whole text me@mail).
  + Added tooltip in find all matches dialog indicating the full
    node path.
  + Improved the tree in links dialog and node change father
    dialog.
  + Added menu item to open the directory containing the
    preferences files.
  + Fixed several bugs.
* Sun Aug 17 2014 dimstar@opensuse.org
- Update to version 0.34.1:
  + Fixed bug introduced in 0.34.0 in search and/or replace, all
    matches.
  + Fixed bug in handling of image format not recognized when
    pasting uri from clipboard.
  + Ctrl+Shift+A not only to show the “Find All Matches” dialog but
    also hide it.
  + Updated translations.
* Sat Aug  9 2014 dimstar@opensuse.org
- Update to version 0.34.0:
  + Implemented the possibility to embed files of any type in the
    cherrytree documents: a clip icon image is inserted in the rich
    text and right clicking on it the file can be saved to a disk
    location. The clip icon size is configurable in the preferences
    dialog.
  + Implemented the possibility to associate links to the images
    through right click menu item. When the image has a link
    associated, a colored arrow is visible over the image.
  + Added right click menu item to insert newline in table cell and
    restored functionality of the shortcut Ctrl+period.
  + Added shortcuts for text Foreground and Background color
    Shift+Alt+F and Shift+Alt+B.
  + Added shortcuts Ctrl+Alt+1, Ctrl+Alt+2 and Ctrl+Alt+3 for lists
    bulleted, numbered and todo.
  + Added shortcuts Ctrl+Plus and Ctrl+Minus to increase/decrease the
    font of tree and text.
  + The number of backups to keep is now configurable.
  + Added import from EssentialPIM HTML file.
  + Fixed several bugs.
  + Handling of cases when dbus is not working properly causing
    Cherrytree not to start, this happens so far only on windows in
    some cases and may be a firewall related problem. In these cases
    the centralized instances control is disabled and cherrytree
    still works.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 0.32.0:
  + When selecting print/export to pdf there’s now an option to
    start new nodes in new pages.
  + The links colors are now configurable.
  + The wrapped lines indentation is now configurable.
  + Added menu item and shortcut (F8) to insert a node with the
    date of today in hierarchy year/month/day.
  + In node properties dialog added the opportunity to insert tags
    choosing between the existing tags.
  + F1 is now shortcut for the online manual.
  + Updated PowerShell syntax highlighting definition file.
  + Fixed several bugs.
- Drop conditional macros used for obsolete openSUSE versions.
* Tue Dec 24 2013 dimstar@opensuse.org
- Update to version 0.31.5:
  + Fixed bug in pasting data from clipboard.
  + Opening a new file from menu it done again in current instance
    (restored old behavior).
  + Bugfix: in links dialog the latest selected node was not
    selected by default anymore.
- Changes from version 0.31.4:
  + Bugfix: cannot change foreground and background color.
  + Bugfix: row wrongly recognized as a list row after pressing
    enter.
  + Updated PowerShell syntax highlighting.
- Changes from version 0.31.3:
  + Updated translations.
- Changes from version 0.31.2:
  + Bugfix: cannot open document if option to reload latest
    document at startup is disabled.
- Changes from version 0.31.1:
  + Bugfix: cannot change node type from rich text to automatic
    syntax highlighting.
  + Bugfix: import from zim errors.
- Changes from version 0.31.0:
  + Added import from one plain text file or a folder of plain text
    files.
  + Added direct export to pdf without going through the print
    dialog, working also in windows without need of installing
    software that creates pdf.
  + Improved the todo lists using different chars (automatic
    conversion) and three states like zim-wiki (not done, done ok
    and done fail).
  + Added function to strip trailing spaces in code nodes (from
    right click menu).
  + Ctrl+Shift+E to expand all nodes, Ctrl+Shift+L to collapse all
    nodes.
  + When opening new file or starting a new empty file will do it
    on a new window if the current is not empty.
  + Right click on a link lets you choose to edit/cut/copy/dismiss/
    delete the underlying link.
  + It is now possible to insert a link if no text is selected, the
    link name will be asked in this case.
  + Added line num column in search all matches list dialog.
  + Added syntax highlighting for PowerShell.
  + Fixed bugs.
  + updated translations.
* Fri Aug 30 2013 zaitor@opensuse.org
- Update to version 0.30.5:
  + Fixed critical bug that caused loss of unsaved data after
    import of nodes from a cherrytree document of type sqlite
    unprotected to sqlite protected.
  + bugfix: node position in the tree after imports.
  + bugfix: TOC generation for selected node and subnodes.
- Changes from version 0.30.4:
  + Fixed critical bug causing loss of data in cherrytree when
    using sqlite as data storage type.
  + Fixed bug: middle (or wheel) click on tree node to
    expand/collapse.
  + Improved paste of data from web page selection.
- Changes from version 0.30.2:
  + cherrytree can now work also without python-enchant installed,
    in this case it is not possible to activate spell check in the
    preferences dialog.
  + Double click on a node or enter key press on a node now toggles
    expanded/collapsed state (before entered node properties
    dialog).
  + Updated translations.
* Sat Aug 24 2013 zaitor@opensuse.org
- Update to version 0.30.1:
  + License change GPLV2+ to GPLV3+.
  + Fixed bug with error dialog with autosave and tree empty.
- Changes from version 0.30.0:
  + Added spell check using the library pygtkspellcheck (which uses
    pyenchant).
  + Added opportunity to insert special characters in text using
    top menu or right click menu. It is possible to edit the
    default list of characters in the preferences dialog.
  + Added export to single plain text file.
  + Improved TOC of the whole tree including links to all existing
    nodes of the tree, not only those with tags h1, h2 and h3.
  + Added menu item and shortcut (Ctrl+Shift+J) to expand/collapse
    the selected tree node.
  + Added shortcut to remove formatting from selected rich text
    (Ctrl+Shift+R).
  + Added basic import from keynote (.knt).
  + Added configurable option to enable/disable the option to
    reload the document from the last session at application start
  (before it was always enabled).
  + Fixed bug in shortcut to paste to rich text node as plain text,
    discarding formatting (Ctrl+Shift+V).
  + Fixed several bugs in export to HTML and PDF.
  + Fixed bugs in import from Zim, Tomboy and Gnote.
  + Fixed several other bugs.
  + Updated translations.
- Add python-enchant BuildRequires, new dependency.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 0.29.4:
  + The color chooser palette keeps now memory of the latest 20
    colors used.
  + In the export to plain text of the rich text nodes, codeboxes
    and tables are also included.
  + Fixed a couple of minor bugs.
- Changes from version 0.29.3:
  + Bugfix: problem of file paths with non ascii characters.
  + Bugfix: unwanted expanding of nodes when adding child node.
  + Bugfix: window position not restored in xfce window manager
    after hide() and show().
  + Bugfixes in print to pdf.
  + Bugfixes in pasting tables from web pages to rich text nodes.
  + Several icons were changed adding a border to make them visible
    in dark themes.
  + The latest palette for foreground and background is restored in
    new sessions.
- Changes from version 0.29.2:
  + Bugfix: scrollbar position not restored when going back to an
    already visited node.
  + Bugfix: on windows os error when using filenames including non
    latin characters.
  + Added back support for pygtk versions < 2.22 (broken in 0.29
    and 0.29.1).
- Changes from version 0.29.1:
  + Updated Chinese, Spanish and German languages.
  + Added limit of recent documents to 10.
  + Added back support for python versions < 2.7 (broken in 0.29).
- Changes from version 0.29:
  + Several bugs fixed.
  + When running cherrytree from command line it is possible to
    indicate a node name to focus as argument (cherrytree filepath
  - n nodename).
  + Added shortcut to toggle focus between tree and text (Ctrl+J).
  + Updated several icons related to text formatting to have an
    unique style/theme for all of them.
  + Added the preferences option to collapse all nodes when loading
    the tree (now there are the options to expand all, collapse all
    or restore from latest session).
  + Added import from zim.
* Fri Nov 30 2012 dimstar@opensuse.org
- Update to version 0.28.5:
  + Fixed several bugs:
  + Export to html: the font of tree and text is now set to the one
    in use in cherrytree at export time.
- Changes from version 0.28.4:
  + fixed internationalization/localization bugs and other minor
    bugs.
- Changes from version 0.28.3:
  + Updated translations.
- Changes from version 0.28.2:
  + Fixed bugs: cannot "save file as" in 0.28.1.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 0.28.1:
  + Fixed several bugs.
  + ctrl+period inserts a newline in a table cell.
* Thu Oct 11 2012 dimstar@opensuse.org
- Update to version 0.28:
  + reduced the size of the preferences dialog adopting tabs.
  + some special symbols are automatically inserted after typing
    the characters that compose them followed by spacebar; ctrl+z
    undoes the replacement.
  + added import from Mempad.
  + fixed several bugs.
* Sun Sep 23 2012 dimstar@opensuse.org
- Update to version 0.27.1:
  + Fixed bug: print / save as pdf of the whole tree not working in
    0.27.
* Sat Sep 22 2012 dimstar@opensuse.org
- Update to version 0.27:
  + Added preference option to enable the periodic check of the
    cherrytree document file for external updates
  + Added preference option to choose between appindicator and
    systray for panel docking
  + Added opportunity to restore the latest search all matches
    dialog with shortcut (Ctrl+Shift+A)
  + Added preference options for text and tree to choose between
    dark theme, light theme or custom colors
  + Added the opportunity to print / save as pdf / export of the
    selected text only
  + Added the opportunity to include the node name in print / save
    as pdf
  + Added import from Gnote
  + Shortcut for paste as plain text in rich text node
    (Ctrl+Shift+V)
  + Adopted python ConfigParser for saving preferences, old
    preferences will be lost
  + Fixed several bugs.
* Sun Jul 22 2012 zaitor@opensuse.org
- Update to version 0.26.3:
  + Bug fixes.
* Tue Jun 12 2012 dimstar@opensuse.org
- Update to version 0.26.2:
  + Bug fixes.
* Mon Jun 11 2012 dimstar@opensuse.org
- Update to version 0.26.1:
  + Fixed minor bug
  + Updated translations.
* Thu May 17 2012 dimstar@opensuse.org
- Update to version 0.26:
  + WARNING: documents edited with a version >= 0.26 cannot be
    edited again with a version < 0.26.
  + added text formatting superscript, subscript, monospace and h3.
  + h1, h2 and h3 formatting is now automatically applied to the
    whole row.
  + the switch between rich text and automatic syntax highlighting
    for the nodes is now simpler.
  + the dialog to choose the file storage type is now file
    extension oriented.
  + it is now possible to configure the default rich text
    foreground and background, so is for the tree.
  + the horizontal rule inserted characters are now configurable.
  + the TOC now includes h3 and can be created also for the whole
    tree.
  + the links anchors size is now configurable.
  + fixed several bugs.
  + we have now a complete manual of the application linked at
    help–manual.
* Fri Feb 24 2012 vuntz@opensuse.org
- Update to version 0.25.4:
  + Bug fixes.
* Sat Feb  4 2012 zaitor@opensuse.org
- Update to version 0.25.3:
  + Bug fixes.
* Tue Jan 24 2012 vuntz@opensuse.org
- Update to version 0.25.2:
  + Bug fixes.
* Sat Jan 21 2012 vuntz@opensuse.org
- Update to version 0.25.1:
  + Middle click on the tree expands/collapses
  + Bug fixes.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 0.25:
  + Add support for a database format, in addition to XML format.
  + Various bug fixes.
  + Updated translations.
* Wed Jan  4 2012 vuntz@opensuse.org
- Update to version 0.24:
  + Add AppIndicator support.
  + Add options: show white spaces, highlight current line,
    gtksouceview style scheme.
  + Make it possible to move a row up/down.
  + Various bug fixes.
  + Updated translations.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 0.23.1:
  + Handle double-click on bookmarks
  + Fix bugs in find all matches
- Stop manually removing cherrytree.glade.h: it is now gone.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 0.23:
  + The limit of undoable steps per node is now configurable (lower
    the limit to save ram).
  + Add iterated find dialog.
  + Add timestamp insert utility.
  + Various bug fixes.
  + Updated translations.
* Fri Jul 15 2011 malcolmlewis@opensuse.org
- Update to version 0.22.2:
  + Fixed minor bugs.
  + Updated translations.
- Remove incorrectly installed header file from translation
  update.
* Thu Jun 23 2011 dimstar@opensuse.org
- Update to version 0.22.1:
  + Add .txt extension to single files of export to plain text
  + Improve import from clipboard html
  + Fix bug when pasting web url from clipboard
- Stop using source services, as Factory is moving away from it.
* Wed Jun  8 2011 dimstar@opensuse.org
- Update to version 0.22:
  + Add the right click option ‘paste as plain text’ to the rich
    text nodes
  + Add imports from tomboy and knowit
  + All the exports (pdf/html/txt/ctd) now offer the options: only
    current node / current node and subnodes / all the tree
  + Implement simple clickable to-do lists.
  + Fix misc bugs
* Tue May  3 2011 dimstar@opensuse.org
- Update to version 0.21.3:
  + Fixed bug involving the formatting property 'small'
  + Fixed shortcut for node deletion not working
  + Updated translations.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to 0.21.2:
  + fixed minor bugs.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 0.21.1:
  + create config directory on startup
- Convert to source service: download_url, recompress and
  set_version.
* Tue Apr 26 2011 badshah400@gmail.com
- Update to version 0.21
  + fixed bugs
  + added links to folders
  + added custom action for clicked link to files and folders
  + added some customizable properties to the codeboxes
  + added fullscreen mode
  + implemented the cut/copy/paste of a table row
  + tables: keyboard navigation across cells, rows, etc.
  + now multiple instances are allowed and handled
  + added the opportunity to sort the whole tree
  + improvements to the find utility while searching patterns in a
    table/codebox
* Tue Mar 15 2011 badshah400@gmail.com
- Update to version 0.20.1:
  + Critical bug fixes
  + Support keyboard based moving of selected item among all the
    tree nodes
* Tue Mar  1 2011 badshah400@gmail.com
- Update to version 0.20:
  + New features:
  - Nodes can now be read-only
  - Easily open recently opened documents
  - Import from leo outliner
  - Utilities to cut/copy the whole underlying row
  - History of visited notes with option to go back/forward
  - Bookmark handling
  - Generate index.html when exporting tree to html
  - Remember latest picked color for background/foreground
  + Bug fixes
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Remove shared-mime-info Requires: if it's not there, then we
  simply don't need to update the mime database.
* Wed Jan 19 2011 badshah400@gmail.com
- Update to version 0.19.3:
  + Bug fixes with tree nodes drag and drop
  + In the anchor insert dialog, fix cursor to lie always in the
    entry text field
* Sun Jan 16 2011 badshah400@gmail.com
- Update to version 0.19.2:
  + Bug fixes
  + Improved text duplication functionality, introducing rich text
    duplication
- Changes from version 0.19.1
  + Bug fixes
  + Tree nodes drag and drop implemented
  + Updated French localization
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 0.19:
  + Write a backup of old file when saving.
  + Add support for a password-protected format.
  + Add a "toggle case" feature.
  + Small bug fixes.
  + Updated translations.
- Add p7zip Recommends to support the password-protected format.
- Re-add the removal of cherrytree.glade.h: the file is still
  installed, and it shouldn't.
* Wed Dec 29 2010 badshah400@gmail.com
- Update to version 0.18.1:
  + Bug fixes and memory usage improvements
  + Update copyright year to 2011
- Changes from version 0.18:
  + Documents edited with 0.18 cannot be opened with earlier
    cherrytree versions
  + Option to specify tags for a node to use when searching for a
    node
  + Implemented export to plain text document
  + Implemented import from treepad lite
  + Introduced submenus in tree menu
  + Added option to display the tree on the right side rather than
    on the left (default)
  + Copy/paste of a selection now works also for images
  + Added Galician language
  + Bug fixes
- Remove spec file hackery to delete unnecessary source files in
  installed package -- taken care of upstream
* Sat Dec 18 2010 badshah400@gmail.com
- Update to version 0.17.1:
  + Fixed copy/paste bugs
- Fix build issues with openSUSE 11.1 and 11.2
* Wed Dec 15 2010 badshah400@gmail.com
- Update to version 0.17:
  + Many copy/paste improvements.
  + Nodes import: it is now possible to specify where to attach
    them
  + Tree nodes sorting is now case insensitive
  + Various bug fixes.
  + Updated translations.
* Thu Nov 25 2010 badshah400@gmail.com
- Update to version 0.16:
  + Improved printing of codeboxes/code nodes
  + Implemented neutral nodes icons/hide nodes icons
  + New: export whole tree or a single node to html
  + New: insert table-of-contents for node
- Recommend lang package instead of Requiring it
* Fri Oct 22 2010 dimstar@opensuse.org
- Update to version 0.15:
  + Improved the find/replace utility adding the 'all matches'
    option which allows to find/replace all matches at once and
    list the results
  + Fixed find/replace bugs
  + Added the menu item (help--check newer version) and preferences
    dialog option to automatically check for newer version
  + Fixed bugs in the import from basket
  + Fixed bug in the printing of codeboxes bigger than the A4 size
  + Fixed bug in bulleted and numbered lists
  + Added the find/replace menu items to right click menus,
    reorganized some menu items
  + When inserting a codebox, if some text is highlighted it will
    be automatically moved into the codebox
  + Fixed bug crashing the app when closing from top right cross
    and then selecting cancel.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.14.2:
  + Removed the shebang lines from the top of non executable
    python source files
  + Changed the cherrytree process name from python to cherrytree
  + Improved import from basket
  + Fixed codebox print/save as pdf bugs
  + Rearranged the messy rich text right click menu
- Drop cherrytree-remove-shebang-line.patch: fixed upstream.
* Mon Sep 13 2010 dimstar@opensuse.org
- Update to version 0.14.1:
  + added Ukrainian and French languages.
* Tue Sep  7 2010 coolo@novell.com
- Fix build with python 2.7, by fixing a filename in the file list.
* Mon Aug 30 2010 badshah400@gmail.com
- Removed unsafe sed hack from spec file to delete unnecessary
  shebang lines in favour of cherrytree-remove-shebang-line.patch
- Cleanup of spec file
* Fri Aug 27 2010 badshah400@gmail.com
- Fix build errors
* Fri Aug 27 2010 badshah400@gmail.com
- Initial package (version 0.14)
